"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ErrorMessage = exports.ErrorType = exports.WarningMessage = exports.WarningType = exports.Message = exports.LocalizableStringSet = exports.createLocalizableStringSet = exports.LocalizedStringSet = exports.LocalizableString = exports.LocalizedString = exports.Culture = void 0;
const zod_1 = require("zod");
exports.Culture = zod_1.z.string().regex(/^[a-z]{2}(-[A-Z]{2})?$/);
exports.LocalizedString = zod_1.z.tuple([exports.Culture, zod_1.z.string()]);
exports.LocalizableString = zod_1.z.record(exports.Culture, zod_1.z.string());
exports.LocalizedStringSet = zod_1.z.tuple([exports.Culture, zod_1.z.record(zod_1.z.string())]);
function createLocalizableStringSet(stringSet) {
    return zod_1.z.record(exports.Culture, stringSet);
}
exports.createLocalizableStringSet = createLocalizableStringSet;
exports.LocalizableStringSet = zod_1.z.lazy(() => exports.LocalizableStringSet);
exports.Message = zod_1.z.object({
    type: zod_1.z.string(),
    code: zod_1.z.string(),
    parameters: zod_1.z.record(zod_1.z.string()).optional(),
    issuer: zod_1.z.string().optional(),
    localizableStringSet: exports.LocalizableStringSet.optional(),
    localizedstring: exports.LocalizedString.optional(),
});
var WarningType;
(function (WarningType) {
    WarningType["Warn"] = "WARN";
})(WarningType || (exports.WarningType = WarningType = {}));
exports.WarningMessage = exports.Message.extend({
    type: zod_1.z.nativeEnum(WarningType),
});
var ErrorType;
(function (ErrorType) {
    ErrorType["AccessDenied"] = "ACCESS_DENIED";
    ErrorType["ProcessError"] = "PROCESS_ERROR";
    ErrorType["UnknownResource"] = "UNKNOWN_RESOURCE";
    ErrorType["TechnicalIssue"] = "TECHNICAL_ISSUE";
})(ErrorType || (exports.ErrorType = ErrorType = {}));
exports.ErrorMessage = exports.Message.extend({
    type: zod_1.z.nativeEnum(ErrorType),
});
